@@ -37,7 +37,6 @@ def audit_m2m_change(sender, **kwargs):
             dict_["new_state"] = m2m_audit.get_m2m_values_for(instance=instance)
             dict_["m2m_change"] = True
             cache.set(cache_key, dict_, DEFAULT_CACHE_TIMEOUT)
-            print "\t >>>>> %s" % pprint(dict_)
             save_audit(instance, Audit.CHANGE, kwargs=dict_)
         elif kwargs['action'] == "pre_remove":
             pass
@@ -64,8 +63,6 @@ def audit_pre_save(sender, **kwargs):
                 dict_["old_state"] = m2m_audit.get_m2m_values_for(instance=instance)
                 cache.set(cache_key, dict_, DEFAULT_CACHE_TIMEOUT)
                 LOG.debug("old_state saved in cache with key %s for m2m auditing" % cache_key)
-                print "old_state: %s" % pprint(dict_)
-                print "*" * 50
         save_audit(kwargs['instance'], Audit.CHANGE)
 
 
@@ -74,6 +71,8 @@ def audit_pre_delete(sender, **kwargs):
 
 
 def register(*my_models):
+    if not settings.DJANGO_SIMPLE_AUDIT_ACTIVATED:
+        return False
     global MODEL_LIST
     for model in my_models:
         if model is not None:
@@ -90,7 +89,9 @@ def register(*my_models):
                     for m2m in m2ms:
                         try:
                             sender_m2m = getattr(model, m2m[0].name).through
-                            models.signals.m2m_changed.connect(audit_m2m_change, sender=sender_m2m)
+                            if sender_m2m.__name__ == "{}_{}".format(model.__name__, m2m[0].name):
+                                models.signals.m2m_changed.connect(audit_m2m_change, sender=sender_m2m)
+                                LOG.debug("Attached signal to: %s" % sender_m2m)
                         except Exception, e:
                             LOG.warning("could not create signal for m2m field: %s" % e)
 
